@@ -17,14 +17,15 @@ LOG_ERROR = True
 # logging.print_datetime
 #
 def print_datetime(arg1, arg2=''):
-    cprint(
-        f'{current_thread().getName()} {datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")}'
-        color='cyan',
+    print(f'{current_thread().getName()} {datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")}')
     cprint(
         arg1,
         color='bright_white'
     )
-    print(f' {arg2}')
+    cprint(
+        f' {arg2}',
+        color='cyan'
+    )
 
 # logging.getMillis
 #
@@ -79,7 +80,7 @@ def log_error(traceback, message):
     EngineMonitorEvent().pushEvent(
         {"type": "error", "message": message, "exception": traceback.format_exc()})
     if LOG_DEBUG:
-        formatted_lines=traceback.format_exc().splitlines()
+        formatted_lines = traceback.format_exc().splitlines()
         print_datetime(
             f'ERROR## 🟥 {message}\n     ## Message: {formatted_lines[-1]}')
         traceback.print_exc()
