@@ -7,6 +7,7 @@ import os.path
 import traceback
 
 from pwbus.commons.logging import *
+from pwbus.commons.cprint import cprint
 
 # DynamicTask
 #
@@ -27,21 +28,21 @@ class DynamicTask():
             return
 
         try:
-            cprint(
-            module=importlib.import_module(module_name)
-            class_=getattr(module, class_name)
-            print()
-            self.instance=class_(payload)
+            module = importlib.import_module(module_name)
+            class_ = getattr(module, class_name)
+            if isDebugEnabled:
+                cprint(f'----(start task {module}.{class_name})-----------------------')
+            self.instance = class_(payload)
             if isDebugEnabled:
                 log_debug(
                     f'DynamicTask - Module [{module_name}] Class [{class_name}] instance created')
-            print()
+                cprint(f'----(enf of task {module}.{class_name})----------------------')
 
         except:
-            formatted_lines=traceback.format_exc().splitlines()
+            formatted_lines = traceback.format_exc().splitlines()
             log_debug(
                 f'⚠️ DynamicTask - WARNING!!! Cannot instatiate class -  task_id [{task_id}] - Message: {formatted_lines[-2]} | {formatted_lines[-1]}')
-            payload['errorOnTask']=formatted_lines[-1]
+            payload['errorOnTask'] = formatted_lines[-1]
 
             traceback.print_exc()
             raise
